@@ -6,7 +6,7 @@ IRI - Internationalized Resource Identifiers
 
 =head1 VERSION
 
-This document describes IRI version 0.009
+This document describes IRI version 0.010
 
 =head1 SYNOPSIS
 
@@ -80,7 +80,7 @@ Returns the respective component of the parsed IRI.
 	package IRI; 
 	use v5.10.1;
 	use warnings;
-	our $VERSION	= '0.009';
+	our $VERSION	= '0.010';
 	use Moo;
 	use MooX::HandlesVia;
 	use Types::Standard qw(Str InstanceOf HashRef Bool);
@@ -337,11 +337,13 @@ Returns the respective component of the parsed IRI.
 				}
 			} else {
 				if ($components{user} or $components{port} or defined($components{host})) {
-					foreach my $k (qw(scheme user port host path query)) {
+					foreach my $k (qw(scheme user port host query)) {
 						if (exists $components{$k}) {
 							$target{$k} = $components{$k};
 						}
 					}
+					my $path		= $components{path};
+					$target{path}	= $self->_remove_dot_segments($path);
 				} else {
 					if ($components{path} eq '') {
 						$target{path}	= $base{path};
